@@ -25,12 +25,12 @@
 int main(int argc, char *argv[])
 {
 	QApplication app(argc, argv);
-	//QApplication app(argc, argv);
 	QUrl url("ftp://ftp.riken.jp/Linux/fedora/");
 	QString version;
-	if (argc >= 2)
+	if (argc >= 2){
 		url = argv[1];
 		version = argv[2];
+	}
 	Downloader downloader(url, version);
 	QObject::connect(&downloader, SIGNAL(finished()),
 		&app, SLOT(quit()));
