@@ -91,6 +91,7 @@
 #include "semanage_core_translation_process.h"
 #include "semanage_core_boolean_process.h"
 #include "semanage_core_permissive_process.h"
+#include "seinfo.h"
 #include "autorelabel.h"
 #include "policygeneration.h"
 #include "aureport.h"
@@ -101,6 +102,7 @@
 #include "mainwindow.h"
 #include "downloader.h"
 #include "sqlrefpolicy.h"
+#include "semodule_dontaudit.h"
 
  MainWindow::MainWindow()
 {
@@ -138,6 +140,7 @@
 	semanage_core_translation_process_o = 0;
 	semanage_core_boolean_process_o = 0;
 	semanage_core_permissive_process_o = 0;
+	seinfo_o = 0;
 	autorelabel_process_o = 0;
 	policygeneration_process_o = 0;
 	aureport_o = 0;
@@ -147,6 +150,10 @@
 	restorecon_o = 0;
 	downloader_o = 0;
 	sqlrefpolicy_o = 0;
+	semodule_dontaudit_o = 0;
+
+	//semodule_dontaudit_o = new SemoduleDontaudit(this);
+	//semodule_dontaudit_o->semodule_dontaudit_base_process();
 
 	createActions();
 	createMenus();
@@ -154,166 +161,85 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.76"));
+	setWindowTitle(tr("segatex-7.775"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
- }
-void MainWindow::updateSegatexStateIndicator()
-{
-	selinux_policy = segatex_state->loaded_policy();
-	enabled_or_not_str = segatex_state->is_selinux_enabled_segatex();
-	getenforce_str = segatex_state->getenforce_segatex();
-	if(enabled_or_not_str == "disabled")
-	{
-	selinux_policy = "SELinux is fully " + enabled_or_not_str + ".";
-	segatexStateLabel->setPaletteBackgroundColor(QColor(255, 122, 162));
-	}
-	else
-	{
-	selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use.";
-		if(getenforce_str == "enforcing")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
-		if(getenforce_str == "permissive")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(255, 251, 126));
-	}
-	segatexStateLabel->clear();
-	segatexStateLabel->setText(tr(selinux_policy));
+	//for test
+	//audit2allow();
 }
-void MainWindow::openFile(const QString &fileName)
+void MainWindow::createMenus()
 {
-    Editor *editor = createEditor();
-    if (editor->openFile(fileName))
-        editor->show();
-    else
-        editor->close();
+	fileMenu = menuBar()->addMenu(tr("&File"));
+	fileMenu->addAction(newAct);
+	fileMenu->addAction(openAct);
+	fileMenu->addAction(saveAct);
+	fileMenu->addAction(saveAsAct);
+	fileMenu->addSeparator();
+	QAction *action = fileMenu->addAction(tr("Switch layout direction"));
+	connect(action, SIGNAL(triggered()), this, SLOT(switchLayoutDirection()));
+	fileMenu->addAction(exitAct);
+
+	editMenu = menuBar()->addMenu(tr("&Edit"));
+	editMenu->addAction(cutAct);
+	editMenu->addAction(copyAct);
+	editMenu->addAction(pasteAct);
+
+	windowMenu = menuBar()->addMenu(tr("&Window"));
+	updateWindowMenu();
+	connect(windowMenu, SIGNAL(aboutToShow()), this, SLOT(updateWindowMenu()));
+	menuBar()->addSeparator();
+
+	auditMenu = menuBar()->addMenu(tr("&Audit"));
+	auditMenu->addAction(semodule_dontauditAct);
+	auditMenu->addAction(segatex_coreAct);
+	auditMenu->addAction(audit2allowAct);
+	auditMenu->addAction(aureportAct);
+	auditMenu->addAction(ausearchAct);
+
+	policyMenu = menuBar()->addMenu(tr("&Policy"));
+	policyMenu->addAction(sqlrefpolicyAct);
+	policyMenu->addAction(selinuxYumAct);
+	policyMenu->addAction(enforcingAct);
+	policyMenu->addAction(check_selinuxAct);
+	policyMenu->addAction(default_policyAct);
+
+	manageMenu = menuBar()->addMenu(tr("&Modules"));
+	manageMenu->addAction(semodule_core_processAct);
+	manageMenu->addAction(policygeneration_processAct);
+
+	semanageMenu = menuBar()->addMenu(tr("&Semanage"));
+	semanageMenu->addAction(semanage_core_processAct);
+	semanageMenu->addAction(semanage_core_login_processAct);
+	semanageMenu->addAction(semanage_core_fcontext_processAct);
+	semanageMenu->addAction(semanage_core_port_processAct);
+	semanageMenu->addAction(semanage_core_translation_processAct);
+	semanageMenu->addAction(semanage_core_boolean_processAct);
+	semanageMenu->addAction(semanage_core_permissive_processAct);
+	semanageMenu->addAction(seinfoAct);
+
+	relabelMenu = menuBar()->addMenu(tr("Re&label"));
+	relabelMenu->addAction(restoreconAct);
+	relabelMenu->addAction(autorelabel_processAct);
+
+	downloaderMenu = menuBar()->addMenu(tr("&Download"));
+	downloaderMenu->addAction(downloaderAct);
+
+	breakteMenu = menuBar()->addMenu(tr("Break .&te"));
+	breakteMenu->addAction(breakteAct);
+
+	breakifMenu = menuBar()->addMenu(tr("Break .&if"));
+	breakifMenu->addAction(breakifAct);
+
+	miscellaneousMenu = menuBar()->addMenu(tr("Mis&c"));
+	miscellaneousMenu->addAction(useraddAct);
+	miscellaneousMenu->addAction(seeprocessAct);
+
+	helpMenu = menuBar()->addMenu(tr("&Help"));
+	helpMenu->addAction(howtouseAct);
+	helpMenu->addAction(aboutAct);
+	helpMenu->addAction(aboutQtAct);
+
 }
-void MainWindow::closeEvent(QCloseEvent *event)
-{
-	mdiArea->closeAllSubWindows();
-	if (activeMdiChild()) {
-		event->ignore();
-	} else {
-		writeSettings();
-		event->accept();
-	}
-}
- void MainWindow::newFile()
- {
-     MdiChild *child = createMdiChild();
-     child->newFile();
-     child->show();
- }
-void MainWindow::open()
-{
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/usr/share/segatex",tr("Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv);;Any files(*)"));
-	if (!fileName.isEmpty()) {
-		QMdiSubWindow *existing = findMdiChild(fileName);
-		if (existing) {
-			mdiArea->setActiveSubWindow(existing);
-		return;
-		}
-		MdiChild *child = createMdiChild();
-		if (child->loadFile(fileName)) {
-			statusBar()->showMessage(tr("File loaded"), 2000);
-			child->show();
-		} else {
-			child->close();
-		}
-	}
-}
- void MainWindow::save()
- {
-     if (activeMdiChild() && activeMdiChild()->save())
-         statusBar()->showMessage(tr("File saved"), 2000);
- }
- void MainWindow::saveAs()
- {
-     if (activeMdiChild() && activeMdiChild()->saveAs())
-         statusBar()->showMessage(tr("File saved"), 2000);
- }
- void MainWindow::cut()
- {
-     if (activeMdiChild())
-         activeMdiChild()->cut();
- }
- void MainWindow::copy()
- {
-     if (activeMdiChild())
-         activeMdiChild()->copy();
- }
- void MainWindow::paste()
- {
-     if (activeMdiChild())
-         activeMdiChild()->paste();
- }
-void MainWindow::about()
-{
-	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.76</h2>"
-		"<p>Copyright &copy; 2007-2009"
-		"<p>Shintaro Fujiwara."
-		"<p>segatex is a SELinux tool"
-		"<p><b>written with Qt</b>."));
-}
- void MainWindow::updateMenus()
- {
-     bool hasMdiChild = (activeMdiChild() != 0);
-     saveAct->setEnabled(hasMdiChild);
-     saveAsAct->setEnabled(hasMdiChild);
-     pasteAct->setEnabled(hasMdiChild);
-     closeAct->setEnabled(hasMdiChild);
-     closeAllAct->setEnabled(hasMdiChild);
-     tileAct->setEnabled(hasMdiChild);
-     cascadeAct->setEnabled(hasMdiChild);
-     nextAct->setEnabled(hasMdiChild);
-     previousAct->setEnabled(hasMdiChild);
-     separatorAct->setVisible(hasMdiChild);
-     bool hasSelection = (activeMdiChild() &&
-                          activeMdiChild()->textCursor().hasSelection());
-     cutAct->setEnabled(hasSelection);
-     copyAct->setEnabled(hasSelection);
- }
- void MainWindow::updateWindowMenu()
- {
-     windowMenu->clear();
-     windowMenu->addAction(closeAct);
-     windowMenu->addAction(closeAllAct);
-     windowMenu->addSeparator();
-     windowMenu->addAction(tileAct);
-     windowMenu->addAction(cascadeAct);
-     windowMenu->addSeparator();
-     windowMenu->addAction(nextAct);
-     windowMenu->addAction(previousAct);
-     windowMenu->addAction(separatorAct);
-     QList<QMdiSubWindow *> windows = mdiArea->subWindowList();
-     separatorAct->setVisible(!windows.isEmpty());
-     for (int i = 0; i < windows.size(); ++i) {
-         MdiChild *child = qobject_cast<MdiChild *>(windows.at(i)->widget());
-         QString text;
-         if (i < 9) {
-             text = tr("&%1 %2").arg(i + 1)
-                                .arg(child->userFriendlyCurrentFile());
-         } else {
-             text = tr("%1 %2").arg(i + 1)
-                               .arg(child->userFriendlyCurrentFile());
-         }
-         QAction *action  = windowMenu->addAction(text);
-         action->setCheckable(true);
-         action ->setChecked(child == activeMdiChild());
-         connect(action, SIGNAL(triggered()), windowMapper, SLOT(map()));
-         windowMapper->setMapping(action, windows.at(i));
-     }
- }
- MdiChild *MainWindow::createMdiChild()
- {
-     MdiChild *child = new MdiChild;
-     mdiArea->addSubWindow(child);
-     connect(child, SIGNAL(copyAvailable(bool)),
-             cutAct, SLOT(setEnabled(bool)));
-     connect(child, SIGNAL(copyAvailable(bool)),
-             copyAct, SLOT(setEnabled(bool)));
-     return child;
- }
 void MainWindow::createActions()
 {
 	newAct = new QAction(QIcon(":/images/new.png"), tr("&New"), this);
@@ -459,6 +385,11 @@ void MainWindow::createActions()
 	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(yum_selinux_process()));
 	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	semodule_dontauditAct = new QAction(tr("dont&audit"), this);
+	semodule_dontauditAct->setStatusTip(tr("manage don't audit"));
+	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(semodule_dontaudit()));
+	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	audit2allowAct = new QAction(tr("&Audit2allow"), this);
 	audit2allowAct->setStatusTip(tr("audit2allow"));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
@@ -499,15 +430,20 @@ void MainWindow::createActions()
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(semanage_core_translation_process()));
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), this);
+	semanage_core_boolean_processAct->setStatusTip(tr("setsebool [-P] boolean value."));
+	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(semanage_core_boolean_process()));
+	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	semanage_core_permissive_processAct = new QAction(tr("semanage &permissive"), this);
 	semanage_core_permissive_processAct->setStatusTip(tr("Semanage permissive -a -d."));
 	connect(semanage_core_permissive_processAct, SIGNAL(activated()), this, SLOT(semanage_core_permissive_process()));
 	connect(semanage_core_permissive_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), this);
-	semanage_core_boolean_processAct->setStatusTip(tr("setsebool [-P] boolean value."));
-	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(semanage_core_boolean_process()));
-	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+	seinfoAct = new QAction(tr("se&info"), this);
+	seinfoAct->setStatusTip(tr("Seinfo [options]"));
+	connect(seinfoAct, SIGNAL(activated()), this, SLOT(seinfo()));
+	connect(seinfoAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 	autorelabel_processAct = new QAction(tr("auto&relabel "), this);
 	autorelabel_processAct->setStatusTip(tr("autorelabel the system."));
@@ -548,77 +484,169 @@ void MainWindow::createActions()
 	downloaderAct->setStatusTip(tr("download Fedora"));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(downloader()));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semodule_dontauditAct = new QAction(tr("dont&audit"), this);
+	semodule_dontauditAct->setStatusTip(tr("manage dontaudit"));
+	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(semodule_dontaudit()));
+	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
-void MainWindow::createMenus()
+
+
+void MainWindow::updateSegatexStateIndicator()
 {
-	fileMenu = menuBar()->addMenu(tr("&File"));
-	fileMenu->addAction(newAct);
-	fileMenu->addAction(openAct);
-	fileMenu->addAction(saveAct);
-	fileMenu->addAction(saveAsAct);
-	fileMenu->addSeparator();
-	QAction *action = fileMenu->addAction(tr("Switch layout direction"));
-	connect(action, SIGNAL(triggered()), this, SLOT(switchLayoutDirection()));
-	fileMenu->addAction(exitAct);
-
-	editMenu = menuBar()->addMenu(tr("&Edit"));
-	editMenu->addAction(cutAct);
-	editMenu->addAction(copyAct);
-	editMenu->addAction(pasteAct);
-
-	windowMenu = menuBar()->addMenu(tr("&Window"));
-	updateWindowMenu();
-	connect(windowMenu, SIGNAL(aboutToShow()), this, SLOT(updateWindowMenu()));
-	menuBar()->addSeparator();
-
-	auditMenu = menuBar()->addMenu(tr("&Audit"));
-	auditMenu->addAction(segatex_coreAct);
-	auditMenu->addAction(audit2allowAct);
-	auditMenu->addAction(aureportAct);
-	auditMenu->addAction(ausearchAct);
-
-	policyMenu = menuBar()->addMenu(tr("&Policy"));
-	policyMenu->addAction(sqlrefpolicyAct);
-	policyMenu->addAction(selinuxYumAct);
-	policyMenu->addAction(enforcingAct);
-	policyMenu->addAction(check_selinuxAct);
-	policyMenu->addAction(default_policyAct);
-
-	manageMenu = menuBar()->addMenu(tr("&Modules"));
-	manageMenu->addAction(semodule_core_processAct);
-	manageMenu->addAction(policygeneration_processAct);
-
-	semanageMenu = menuBar()->addMenu(tr("&Semanage"));
-	semanageMenu->addAction(semanage_core_processAct);
-	semanageMenu->addAction(semanage_core_login_processAct);
-	semanageMenu->addAction(semanage_core_fcontext_processAct);
-	semanageMenu->addAction(semanage_core_port_processAct);
-	semanageMenu->addAction(semanage_core_translation_processAct);
-	semanageMenu->addAction(semanage_core_boolean_processAct);
-	semanageMenu->addAction(semanage_core_permissive_processAct);
-
-	relabelMenu = menuBar()->addMenu(tr("Re&label"));
-	relabelMenu->addAction(restoreconAct);
-	relabelMenu->addAction(autorelabel_processAct);
-
-	downloaderMenu = menuBar()->addMenu(tr("&Download"));
-	downloaderMenu->addAction(downloaderAct);
-
-	breakteMenu = menuBar()->addMenu(tr("Break .&te"));
-	breakteMenu->addAction(breakteAct);
-
-	breakifMenu = menuBar()->addMenu(tr("Break .&if"));
-	breakifMenu->addAction(breakifAct);
-
-	miscellaneousMenu = menuBar()->addMenu(tr("Mis&c"));
-	miscellaneousMenu->addAction(useraddAct);
-	miscellaneousMenu->addAction(seeprocessAct);
-
-	helpMenu = menuBar()->addMenu(tr("&Help"));
-	helpMenu->addAction(howtouseAct);
-	helpMenu->addAction(aboutAct);
-	helpMenu->addAction(aboutQtAct);
-
+	selinux_policy = segatex_state->loaded_policy();
+	enabled_or_not_str = segatex_state->is_selinux_enabled_segatex();
+	getenforce_str = segatex_state->getenforce_segatex();
+	if(enabled_or_not_str == "disabled")
+	{
+	selinux_policy = "SELinux is fully " + enabled_or_not_str + ".";
+	segatexStateLabel->setPaletteBackgroundColor(QColor(255, 122, 162));
+	}
+	else
+	{
+	selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use.";
+		if(getenforce_str == "enforcing")
+			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
+		if(getenforce_str == "permissive")
+			segatexStateLabel->setPaletteBackgroundColor(QColor(255, 251, 126));
+	}
+	segatexStateLabel->clear();
+	segatexStateLabel->setText(tr(selinux_policy));
+}
+void MainWindow::openFile(const QString &fileName)
+{
+    Editor *editor = createEditor();
+    if (editor->openFile(fileName))
+        editor->show();
+    else
+        editor->close();
+}
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+	mdiArea->closeAllSubWindows();
+	if (activeMdiChild()) {
+		event->ignore();
+	} else {
+		writeSettings();
+		event->accept();
+	}
+}
+ void MainWindow::newFile()
+ {
+     MdiChild *child = createMdiChild();
+     child->newFile();
+     child->show();
+ }
+void MainWindow::open()
+{
+	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/usr/share/segatex",tr("Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv);;Any files(*)"));
+	if (!fileName.isEmpty()) {
+		QMdiSubWindow *existing = findMdiChild(fileName);
+		if (existing) {
+			mdiArea->setActiveSubWindow(existing);
+		return;
+		}
+		MdiChild *child = createMdiChild();
+		if (child->loadFile(fileName)) {
+			statusBar()->showMessage(tr("File loaded"), 2000);
+			child->show();
+		} else {
+			child->close();
+		}
+	}
+}
+ void MainWindow::save()
+ {
+     if (activeMdiChild() && activeMdiChild()->save())
+         statusBar()->showMessage(tr("File saved"), 2000);
+ }
+ void MainWindow::saveAs()
+ {
+     if (activeMdiChild() && activeMdiChild()->saveAs())
+         statusBar()->showMessage(tr("File saved"), 2000);
+ }
+ void MainWindow::cut()
+ {
+     if (activeMdiChild())
+         activeMdiChild()->cut();
+ }
+ void MainWindow::copy()
+ {
+     if (activeMdiChild())
+         activeMdiChild()->copy();
+ }
+ void MainWindow::paste()
+ {
+     if (activeMdiChild())
+         activeMdiChild()->paste();
+ }
+void MainWindow::about()
+{
+	QMessageBox::about(this, tr("About segatex"),
+		tr("<h2>segatex-7.775</h2>"
+		"<p>Copyright &copy; 2007-2009"
+		"<p>Shintaro Fujiwara."
+		"<p>segatex is a SELinux tool"
+		"<p><b>written with Qt</b>."));
+}
+ void MainWindow::updateMenus()
+ {
+     bool hasMdiChild = (activeMdiChild() != 0);
+     saveAct->setEnabled(hasMdiChild);
+     saveAsAct->setEnabled(hasMdiChild);
+     pasteAct->setEnabled(hasMdiChild);
+     closeAct->setEnabled(hasMdiChild);
+     closeAllAct->setEnabled(hasMdiChild);
+     tileAct->setEnabled(hasMdiChild);
+     cascadeAct->setEnabled(hasMdiChild);
+     nextAct->setEnabled(hasMdiChild);
+     previousAct->setEnabled(hasMdiChild);
+     separatorAct->setVisible(hasMdiChild);
+     bool hasSelection = (activeMdiChild() &&
+                          activeMdiChild()->textCursor().hasSelection());
+     cutAct->setEnabled(hasSelection);
+     copyAct->setEnabled(hasSelection);
+ }
+ void MainWindow::updateWindowMenu()
+ {
+     windowMenu->clear();
+     windowMenu->addAction(closeAct);
+     windowMenu->addAction(closeAllAct);
+     windowMenu->addSeparator();
+     windowMenu->addAction(tileAct);
+     windowMenu->addAction(cascadeAct);
+     windowMenu->addSeparator();
+     windowMenu->addAction(nextAct);
+     windowMenu->addAction(previousAct);
+     windowMenu->addAction(separatorAct);
+     QList<QMdiSubWindow *> windows = mdiArea->subWindowList();
+     separatorAct->setVisible(!windows.isEmpty());
+     for (int i = 0; i < windows.size(); ++i) {
+         MdiChild *child = qobject_cast<MdiChild *>(windows.at(i)->widget());
+         QString text;
+         if (i < 9) {
+             text = tr("&%1 %2").arg(i + 1)
+                                .arg(child->userFriendlyCurrentFile());
+         } else {
+             text = tr("%1 %2").arg(i + 1)
+                               .arg(child->userFriendlyCurrentFile());
+         }
+         QAction *action  = windowMenu->addAction(text);
+         action->setCheckable(true);
+         action ->setChecked(child == activeMdiChild());
+         connect(action, SIGNAL(triggered()), windowMapper, SLOT(map()));
+         windowMapper->setMapping(action, windows.at(i));
+     }
+ }
+MdiChild *MainWindow::createMdiChild()
+{
+	MdiChild *child = new MdiChild;
+	mdiArea->addSubWindow(child);
+	connect(child, SIGNAL(copyAvailable(bool)),
+	cutAct, SLOT(setEnabled(bool)));
+	connect(child, SIGNAL(copyAvailable(bool)),
+	copyAct, SLOT(setEnabled(bool)));
+	return child;
 }
  void MainWindow::createToolBars()
  {
@@ -847,6 +875,15 @@ void MainWindow::semanage_core_permissive_process()
 	semanage_core_permissive_process_o->raise();
 	semanage_core_permissive_process_o->setActiveWindow();
 }
+void MainWindow::seinfo()
+{
+	if(!seinfo_o) {
+		seinfo_o = new Seinfo(this);
+	}
+	seinfo_o->show();
+	seinfo_o->raise();
+	seinfo_o->setActiveWindow();
+}
 void MainWindow::autorelabel_process()
 {
 	if(!autorelabel_process_o) {
@@ -919,6 +956,18 @@ void MainWindow::downloader()
 	downloader_o->raise();
 	downloader_o->setActiveWindow();
 }
+void MainWindow::semodule_dontaudit()
+{
+	if(!semodule_dontaudit_o) {
+		semodule_dontaudit_o = new SemoduleDontaudit(this);
+	}else{
+		delete semodule_dontaudit_o;
+		semodule_dontaudit_o = new SemoduleDontaudit(this);
+	}
+	semodule_dontaudit_o->show();
+	semodule_dontaudit_o->raise();
+	semodule_dontaudit_o->setActiveWindow();
+}
 void MainWindow::sqlrefpolicy()
 {
 	//if(!sqlrefpolicy_o) {
