@@ -67,6 +67,7 @@ class SemanageCorePortProcess;
 class SemanageCoreTranslationProcess;
 class SemanageCoreBooleanProcess;
 class SemanageCorePermissiveProcess;
+class Seinfo;
 class AutoRelabel;
 class Policygeneration;
 class Aureport;
@@ -76,6 +77,7 @@ class Seeprocess;
 class Restorecon;
 class Downloader;
 class Sqlrefpolicy;
+class SemoduleDontaudit;
 
 class MainWindow : public QMainWindow
 {
@@ -121,6 +123,7 @@ private slots:
 	void semanage_core_translation_process();
 	void semanage_core_boolean_process();
 	void semanage_core_permissive_process();
+	void seinfo();
 	void autorelabel_process();
 	void policygeneration_process();
 	void aureport();
@@ -130,6 +133,7 @@ private slots:
 	void restorecon();
 	void downloader();
 	void sqlrefpolicy();
+	void semodule_dontaudit();
 private:
 	void createActions();
 	void createMenus();
@@ -198,6 +202,7 @@ private:
 	QAction *semanage_core_translation_processAct;
 	QAction *semanage_core_boolean_processAct;
 	QAction *semanage_core_permissive_processAct;
+	QAction *seinfoAct;
 	QAction *autorelabel_processAct;
 	QAction *policygeneration_processAct;
 	QAction *aureportAct;
@@ -207,6 +212,7 @@ private:
 	QAction *restoreconAct;
 	QAction *downloaderAct;
 	QAction *sqlrefpolicyAct;
+	QAction *semodule_dontauditAct;
 
 	QString selinux_policy;
 	QString enabled_or_not_str;
@@ -231,6 +237,7 @@ private:
 	SemanageCoreTranslationProcess *semanage_core_translation_process_o;
 	SemanageCoreBooleanProcess *semanage_core_boolean_process_o;
 	SemanageCorePermissiveProcess *semanage_core_permissive_process_o;
+	Seinfo *seinfo_o;
 	AutoRelabel *autorelabel_process_o;
 	Policygeneration *policygeneration_process_o;
 	Aureport *aureport_o;
@@ -240,5 +247,6 @@ private:
 	Restorecon *restorecon_o;
 	Downloader *downloader_o;
 	Sqlrefpolicy *sqlrefpolicy_o;
+	SemoduleDontaudit *semodule_dontaudit_o;
 };
 #endif
