@@ -77,7 +77,7 @@ void RestoreconProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
