@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,8 +68,11 @@ private:
 	QLabel *readfromLabel;
 	QLabel *writetoLabel;
 	QLabel *moduleNameLabel;
+	QLabel *grepLabel;
 	QLabel *optionLabel;
 	QLineEdit *moduleNameLineEdit;
+	QLineEdit *grepLineEdit;
+	QString grepLineEdit_str;
 	QLineEdit *writetoLineEdit;
 	Q3TextEdit *textEdit1;
 	QPushButton *audit2allowButton;
