@@ -28,13 +28,14 @@
 
 #include "segatex_audit2allow_process.h"
 
+#include <fstream>
+
 #include <iostream>
 using namespace std;
 
 //default constructor
 SegatexAudit2allowProcess::SegatexAudit2allowProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
-	//setCaption(tr("Audit2allow Process"));
 	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
 	closeButton = new QPushButton(tr("close"), this);
@@ -61,29 +62,9 @@ SegatexAudit2allowProcess::SegatexAudit2allowProcess(QWidget *parent, const char
 void SegatexAudit2allowProcess::close_button_clicked()
 {
 	emit audit2allow_prosess_close_button_clicked();
-
-}
-void SegatexAudit2allowProcess::readFromStdout()
-{
-	QByteArray data = process->readStdout();
-	QString text = textEdit1->text() + QString(data);
-	textEdit1->setText(text);
-}
-void SegatexAudit2allowProcess::processExited()
-{
-	if(process->normalExit()){
-		//textEdit1->append(tr("audit2allow process ended !"));
-		textEdit1->append(tr("\n"));
-	} else {
-		textEdit1->append(tr("audit2allow process had an error !"));
-		textEdit1->append(tr("\n"));
-	}
-	delete process;
-	process = 0;
-	this->setEnabled(true);
 }
 
-void SegatexAudit2allowProcess::audit2allow_base_process(int log_file, QString outputfile_str, int g, QString moduleName_str)
+void SegatexAudit2allowProcess::audit2allow_base_process(int log_file, QString outputfile_str, int g, QString moduleName_str, QString grepLineEdit_str)
 {
 	outputfile_str_common = outputfile_str;
 	rm_outputfile_str_common();
@@ -119,127 +100,112 @@ void SegatexAudit2allowProcess::audit2allow_base_process(int log_file, QString o
 	//devide by   1  eq 1 and % eq  0 option -e
 	//devide by 1000  eq 0 and % eq   0 option -no_option
 
-	this->setEnabled(false);
-	process = new Q3Process(this);
 	path = "/usr/share/segatex";
 	forward_slash = "/";
 	outputfile_str = path + forward_slash + outputfile_str;
-	process->addArgument("rm");
-	process->addArgument(outputfile_str);
-	/*
-	process->addArgument("/usr/sbin/semanage");
-	process->addArgument("permissive");
-	process->addArgument("-a");
-	process->addArgument("segatex_t");
-	*/
-	process->addArgument("audit2allow");
+
+	//grep fusefs /var/log/audit/audit.log | audit2allow -M mycvs
+	
+	process_command = "";
+	
+	if((grepLineEdit_str !="")&&(log_file == 2)){
+		process_command = "grep " + grepLineEdit_str + " /var/log/audit/audit.log | ";
+	}
+	if((grepLineEdit_str !="")&&(log_file == 1)){
+		process_command = "grep " + grepLineEdit_str + " /var/log/messages | ";
+	}
+
+	process_command = process_command + "audit2allow";
 
 	if((x == 1)&&(y == 111)){
-		process->addArgument("-l");
-		process->addArgument("-R");
-		process->addArgument("-v");
-		process->addArgument("-e");
-		//cout << "lrve" << endl;
+		process_command = process_command + " -l -R -v -e"; 
 	}
 	if((x == 1)&&(y == 110)){
-		process->addArgument("-l");
-		process->addArgument("-R");
-		process->addArgument("-v");
-		//cout << "lrv" << endl;
+		process_command = process_command + " -l -R -v"; 
 	}
 	if((x == 1)&&(y == 101)){
-		process->addArgument("-l");
-		process->addArgument("-R");
-		process->addArgument("-e");
-		//cout << "lre" << endl;
+		process_command = process_command + " -l -R -e"; 
 	}
 	if((x == 1)&&(y == 100)){
-		process->addArgument("-l");
-		process->addArgument("-R");
-		//cout << "lr" << endl;
+		process_command = process_command + " -l -R"; 
 	}
 	if((x == 1)&&(y == 11)){
-		process->addArgument("-l");
-		process->addArgument("-v");
-		process->addArgument("-e");
-		//cout << "lve" << endl;
+		process_command = process_command + " -l -v -e"; 
 	}
 	if((x == 1)&&(y == 1)){
-		process->addArgument("-l");
-		process->addArgument("-e");
-		//cout << "le" << endl;
+		process_command = process_command + " -l -e"; 
 	}
 	if((x == 1)&&(y == 10)){
-		process->addArgument("-l");
-		process->addArgument("-v");
-		//cout << "lv" << endl;
+		process_command = process_command + " -l -v"; 
 	}
 	if((x == 1)&&(y == 0)){
-		process->addArgument("-l");
-		//cout << "l" << endl;
+		process_command = process_command + " -l"; 
 	}
 	if((xx == 1)&&(yy == 11)){
-		process->addArgument("-R");
-		process->addArgument("-v");
-		process->addArgument("-e");
-		//cout << "rve" << endl;
+		process_command = process_command + " -R -v -e"; 
 	}
 	if((xx == 1)&&(yy == 10)){
-		process->addArgument("-R");
-		process->addArgument("-v");
-		//cout << "rv" << endl;
+		process_command = process_command + " -R -v"; 
 	}
 	if((xx == 1)&&(yy == 1)){
-		process->addArgument("-R");
-		process->addArgument("-e");
-		//cout << "re" << endl;
+		process_command = process_command + " -R -e"; 
 	}
 	if((xx == 1)&&(yy == 0)){
-		process->addArgument("-R");
-		//cout << "r" << endl;
+		process_command = process_command + " -R"; 
 	}
 	if((xxx == 1)&&(yyy == 1)){
-		process->addArgument("-v");
-		process->addArgument("-e");
-		//cout << "ve" << endl;
+		process_command = process_command + " -v -e"; 
 	}
 	if((xxx == 1)&&(yyy == 0)){
-		process->addArgument("-v");
-		//cout << "v" << endl;
+		process_command = process_command + " -v"; 
 	}
 	if((xxxx == 1)&&(yyyy == 0)){
-		process->addArgument("-e");
-		//cout << "e" << endl;
+		process_command = process_command + " -e"; 
 	}
 	if((x == 0)&&(y == 0)){
 		//do nothing
-		//cout << "nothing" << endl;
 	}
-	process->addArgument("-m");
-	process->addArgument(moduleName_str);
-	if(log_file == 3)
-		process->addArgument("-a");
-	if(log_file == 2){
-		process->addArgument("-i");
-		process->addArgument("/var/log/audit/audit.log");
+	process_command = process_command + " -m " + moduleName_str; 
+
+	if(log_file == 3){
+		process_command = process_command + " -a "; 
 	}
-	if(log_file == 1){
-		process->addArgument("-i");
-		process->addArgument("/var/log/messages");
+
+	if((grepLineEdit_str == "")&&(log_file == 2)){
+		process_command = process_command + " -i /var/log/audit/audit.log"; 
 	}
-	process->addArgument("-o");
-	//path = "/usr/share/segatex";
-	//forward_slash = "/";
-	//outputfile_str = path + forward_slash + outputfile_str;
-	process->addArgument(outputfile_str);
-	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
-	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	process->start();
+	if((grepLineEdit_str == "")&&(log_file == 1)){
+		process_command = process_command + " -i /var/log/messages"; 
+	}
+
+	process_command = process_command + " -o " + outputfile_str; 
+
+        #define PWD_BUF 8600
+        ofstream os_add;
+        os_add.open(outputfile_str);
+        if(os_add){
+                FILE *read_fp;
+                #define SIZE_TMP 8600
+                char buffer[SIZE_TMP];
+                int chars_read;
+                memset(buffer, '\0', sizeof(buffer));
+                read_fp = popen(process_command, "r");
+                if(read_fp != NULL){
+                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        while(chars_read>0){
+                                buffer[chars_read -1] = '\0';
+                                //os << "Reading:-" << endl;
+                                os_add << buffer << endl;
+                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        }
+                        pclose(read_fp);
+                }
+        }
+	os_add.close();
 
 	//read from .te file
 	readFromOutputFile();
 }
-
 //this slot should be called from above slot
 void SegatexAudit2allowProcess::readFromOutputFile()
 {
@@ -259,6 +225,7 @@ void SegatexAudit2allowProcess::readFromOutputFile()
 		while(it_d != files.end()){
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
+			//cout << "file_interface_name" << file_interface_name << endl;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
 				Q3TextStream stream( &file );
@@ -279,9 +246,30 @@ void SegatexAudit2allowProcess::readFromOutputFile()
 void SegatexAudit2allowProcess::rm_outputfile_str_common()
 {
 	outputfile_str_common_real = "/usr/share/segatex/" + outputfile_str_common;
-	this->setEnabled(false);
-	process = new Q3Process(this);
-	process->addArgument("rm");
-	process->addArgument(outputfile_str_common_real);
+
+        #define PWD_BUF 8600
+	rmcommand = "rm " + outputfile_str_common_real;
+
+        ofstream os_rm;
+        os_rm.open(outputfile_str_common_real);
+        if(os_rm){
+                FILE *read_fp;
+                #define SIZE_TMP 8600
+                char buffer[SIZE_TMP];
+                int chars_read;
+                memset(buffer, '\0', sizeof(buffer));
+                read_fp = popen(rmcommand, "r");
+                if(read_fp != NULL){
+                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        while(chars_read>0){
+                                buffer[chars_read -1] = '\0';
+                                //os << "Reading:-" << endl;
+                                os_rm << buffer << endl;
+                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        }
+                        pclose(read_fp);
+                }
+        }
+	os_rm.close();
 }
 
