@@ -275,7 +275,7 @@ if(namedpipeRadioButton->isChecked()){
 	semanageEditLineEdit_str_pp = "semanage fcontext -a -f -p -r " + semanageEditLineEdit7_str + " -t " + semanageEditLineEdit_str + " \"" + semanageEditLineEdit2_str + "\"";
 }
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/add_fcontexted";
+        const char* make_module_file="/usr/share/segatex/semanage/add_fcontexted";
         ofstream os_add;
         os_add.open(make_module_file);
         if(os_add){
@@ -304,7 +304,7 @@ if(namedpipeRadioButton->isChecked()){
 	//cout << "semanageEditLineEdit_str_add_restorecon:" << semanageEditLineEdit_str_add_restorecon << endl;
 	//
         #define PWD_BUF 8600
-        const char* restorecon_file="/root/segatex/semanage/add_fcontexted_restorecon";
+        const char* restorecon_file="/usr/share/segatex/semanage/add_fcontexted_restorecon";
         ofstream os_add_restorecon;
         os_add_restorecon.open(restorecon_file);
         if(os_add_restorecon){
@@ -406,7 +406,7 @@ if(namedpipeRadioButton->isChecked()){
 	semanageEditLineEdit_str_pp = "semanage fcontext -d -f -p -r " + semanageEditLineEdit8_str + " -t " + semanageEditLineEdit3_str + " \"" + semanageEditLineEdit6_str + "\"";
 }
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/delete_fcontexted";
+        const char* make_module_file="/usr/share/segatex/semanage/delete_fcontexted";
         ofstream os_delete;
         os_delete.open(make_module_file);
         if(os_delete){
@@ -432,7 +432,7 @@ if(namedpipeRadioButton->isChecked()){
 	//Now, let's restorecon path
 	semanageEditLineEdit_str_delete_restorecon = "restorecon -R -v " + restorecon_str;
         #define PWD_BUF 8600
-        const char* restorecon_file="/root/segatex/semanage/delete_fcontexted_restorecon";
+        const char* restorecon_file="/usr/share/segatex/semanage/delete_fcontexted_restorecon";
         ofstream os_delete_restorecon;
         os_delete_restorecon.open(restorecon_file);
         if(os_delete_restorecon){
@@ -535,7 +535,7 @@ if(namedpipeRadioButton->isChecked()){
 	semanageEditLineEdit_str_pp = "semanage fcontext -m -f -p -r " + semanageEditLineEdit9_str + " -t " + semanageEditLineEdit4_str + " \"" + semanageEditLineEdit5_str + "\"";
 }
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/modify_fcontexted";
+        const char* make_module_file="/usr/share/segatex/semanage/modify_fcontexted";
         ofstream os_modify;
         os_modify.open(make_module_file);
         if(os_modify){
@@ -561,7 +561,7 @@ if(namedpipeRadioButton->isChecked()){
 	//Now, let's restorecon path
 	semanageEditLineEdit_str_modify_restorecon = "restorecon -R -v " + restorecon_str;
         #define PWD_BUF 8600
-        const char* restorecon_file="/root/segatex/semanage/modify_fcontexted_restorecon";
+        const char* restorecon_file="/usr/share/segatex/semanage/modify_fcontexted_restorecon";
         ofstream os_modify_restorecon;
         os_modify_restorecon.open(restorecon_file);
         if(os_modify_restorecon){
@@ -593,7 +593,7 @@ if(namedpipeRadioButton->isChecked()){
 void SemanageCoreFcontextProcess::semanage_core_base_fcontext_process()
 {
         #define PWD_BUF 8600
-        const char* semanage_fcontext_list_file="/root/segatex/semanage/1_fcontext";
+        const char* semanage_fcontext_list_file="/usr/share/segatex/semanage/1_fcontext";
         ofstream os;
         os.open(semanage_fcontext_list_file);
         if(os){
@@ -625,7 +625,7 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
